# Benchling SDK

A Python 3.8+ SDK for the [Benchling](https://www.benchling.com/) platform designed to provide typed, fluent
interactions with [Benchling APIs](https://docs.benchling.com/reference).

## Installation

Install the dependency via [Poetry](https://python-poetry.org/) (if applicable):

```bash
poetry add benchling-sdk
```
 
Or [Pip](https://pypi.org/project/pip/):
 
```bash
pip install benchling-sdk
```

## Documentation

Documentation for the SDK is kept up-to-date at [docs.benchling.com](https://docs.benchling.com), and you can get started with
it using this guide:
[https://docs.benchling.com/docs/getting-started-with-the-sdk](https://docs.benchling.com/docs/getting-started-with-the-sdk).

## Support

To report issues with using the SDK, contact [support@benchling.com](mailto:support@benchling.com).
